# -*- coding: utf-8 -*-
"""
Include all management modules.
"""
__author__ = 'Matthieu Gallet'
# __copyright__ = "Copyright 2013, 19pouces.net"
# __credits__ = "flanker"
# __maintainer__ = "flanker"
# __email__ = "flanker@19pouces.net"